==> haskell-hsini-0.5.2.2-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hsini
version:              0.5.2.2
visibility:           public
id:                   hsini-0.5.2.2-JAWxzscyxqAGWa0J5i6P9
key:                  hsini-0.5.2.2-JAWxzscyxqAGWa0J5i6P9
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
author:               Magnus Therning <magnus@therning.org>
synopsis:             ini configuration files
description:
    Library for reading and writing configuration files in INI format (see <https://en.wikipedia.org/wiki/INI_file>).

category:             Configuration, Data
abi:                  b2e118d0a4fed46671f38cafc3f3a20c
exposed:              True
exposed-modules:
    Data.Ini Data.Ini.Reader Data.Ini.Reader.Internals Data.Ini.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsini
hs-libraries:         HShsini-0.5.2.2-JAWxzscyxqAGWa0J5i6P9
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-hsini/html/hsini.haddock
haddock-html:         /usr/share/doc/haskell-hsini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsini-0.5.2.2-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hsini
version:              0.5.2.2
visibility:           public
id:                   hsini-0.5.2.2-E7UJBZpZ6XOGqGdkq6R5XE
key:                  hsini-0.5.2.2-E7UJBZpZ6XOGqGdkq6R5XE
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
author:               Magnus Therning <magnus@therning.org>
synopsis:             ini configuration files
description:
    Library for reading and writing configuration files in INI format (see <https://en.wikipedia.org/wiki/INI_file>).

category:             Configuration, Data
abi:                  2bf93aa923771cbe691b3277aa47f24c
exposed:              True
exposed-modules:
    Data.Ini Data.Ini.Reader Data.Ini.Reader.Internals Data.Ini.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsini
hs-libraries:         HShsini-0.5.2.2-E7UJBZpZ6XOGqGdkq6R5XE
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-hsini/html/hsini.haddock
haddock-html:         /usr/share/doc/haskell-hsini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
